"""
Vogel Model Trainer - Train custom bird species classifiers from videos.

This package provides tools for:
- Extracting bird images from videos using YOLO detection
- Organizing datasets for training
- Training custom EfficientNet classifiers
- Testing and evaluating trained models
"""

from vogel_model_trainer.__version__ import __version__

__all__ = ["__version__"]
